jQuery.noConflict();

(function ($, PLUGIN_ID) {
    "use strict";

    var radiobutton_max = 3;
    var pay_check_success = 'お支払い情報が確認できました。';
    var pay_check_false = 'お支払い情報が見つかりません。';
    var cardfg = false;

    var group;

    function payid_ok(payid) {
        //支払いID表示＆編集不可
        $('#payid').disabled = true;
        $('#payid').val(payid);

        //支払い確認ボタン 非表示
        $('#paycheck').hide();

        //カード情報入力フォーム非表示
        $('#carddiv').hide();
        $('#basediv').hide();
    }

    function payid_ng() {
        //支払いID確認ボタン表示
        $('#paycheck').show();

        if (cardfg) {
            //カード情報入力フォーム表示
            $('#carddiv').show();
            $('#basediv').hide();
        } else {
            //カード情報入力フォーム非表示
            $('#carddiv').hide();
            $('#basediv').show();
        }
    }

    function getSubdomain() {
        var subdomain = kintone.api.url('/k/v1/records');
        return subdomain.slice(subdomain.indexOf('/') + 2, subdomain.indexOf('.'));
    }

    function payCheck(PLUGIN_ID, callback) {
        var url = 'https://ca6ouejz4h.execute-api.ap-northeast-1.amazonaws.com/prod/pluginauth';
        var param = {
            param: {
                subdomain: getSubdomain(),
                pluginid: PLUGIN_ID
            }
        }
        kintone.proxy(url, 'POST', {}, param, function (body, status, headers) {
            if (status === 200) {
                var json_body = JSON.parse(body);
                if (json_body.result === 'OK') {
                    callback(true, json_body.message);
                } else {
                    callback(false, json_body.message);
                }
            } else {
                // 200以外はサーバー障害の可能性があるので認証通す
                callback(true, '');
            }
        }, function (body) {
            console.log(body);
            //ネットワークエラー（早めに画面移動してもここにくる、はず）時は、正常に変更
            callback(true, '');
        });
    }

    // 認証後
    var payCheckResult = function (res, result) {
        //resultには、
        //res === true時には注文ID、
        //res === false時にはメッセージが入る
        if (res) {
            //支払いIDフォーム表示
            payid_ok(result);
            document.getElementById('paycheckstatus').innerText = pay_check_success;
            showMessage(pay_check_success + '：' + result, '', 'success');
        } else {
            payid_ng();
            document.getElementById('paycheckstatus').innerText = pay_check_false;
            showMessage(pay_check_false, '', 'warning');
        }
    };

    function checkout(PLUGIN_ID, callback) {
        var url = 'https://t6z41x7av9.execute-api.ap-northeast-1.amazonaws.com/prod/checkout';
        var amount = document.querySelector('select[name="amount"]');
        var token = document.querySelector('input[name="payjp-token"]');
        if (token.value === '') {
            showMessage('カード情報が入力されていません。', '', 'warning');
            document.getElementById('paystatus').innerText = '';
            return;
        }

        var param = {
            param: {
                amount: amount.value,
                pluginid: PLUGIN_ID,
                subdomain: getSubdomain(),
                'payjp-token': token.value
            }
        }
        kintone.proxy(url, 'POST', {}, param, function (body, status, headers) {
            if (status === 200) {
                var json_body = JSON.parse(body);
                if (json_body.result === 'OK') {
                    callback(true, json_body);
                } else {
                    callback(false, json_body);
                }
            } else {
                // 200以外はサーバー障害の可能性があるので認証通す
                callback(true, '');
            }
        }, function (body) {
            console.log(body);
            //ネットワークエラー（早めに画面移動してもここにくる、はず）時は、正常に変更
            callback(true, '');
        });
    }

    // 決済後
    var checkoutResult = function (res, result) {
        //resultには、
        //res === true時には注文ID、
        //res === false時にはメッセージが入る
        document.getElementById('paycheckstatus').innerText = '';
        document.getElementById('paystatus').innerText = result.message;
        if (res) {
            //支払いIDフォーム表示
            payid_ok(result.payid);
            showMessage(result.message, '支払い成功', 'success');
        } else {
            //支払いIDフォーム非表示
            payid_ng();
            showMessage(result.message, '支払い失敗', 'error');
        }
    };

    function showMessage(message, title, type) {
        if (message === 'undefined' || message === '') {
            return;
        }
        title = title || '';
        type = type || 'success'; //"warning", "error", "success" and "info" 

        swal(
                {
                    title: title,
                    text: message,
                    type: type,
                    confirmButtonText: "OK",
                    closeOnConfirm: true
                },
        function () {
            //なにもしない
            ;
        });
    }

    $(document).ready(function () {
        group = new Array();
        kintone.api(kintone.api.url('/k/v1/app/form/fields', true), 'GET', {'app': kintone.app.getId()}, function (resp) {
            var config = kintone.plugin.app.getConfig(PLUGIN_ID);
            $.each(resp['properties'], function (index, property) {
                if (property['type'] === 'RADIO_BUTTON') {
                    var htmllabel = '/';
                    $.each(property['options'], function (index_option, property_option) {
                        htmllabel = htmllabel + property['code'] + '_' + property_option['label'] + '/';
                    });
                    for (var i = 1; i <= radiobutton_max; i++) {
                        $('#plugin-radiobutton-field' + i).append($('<OPTION>').html(htmllabel).val(property['code']));
                    }
                }
                if (property['type'] === 'GROUP') {
                    group.push(property['code']);
                }
            });
            if (config['payid']) {
                $('#payid').val(config['payid']);
                payid_ok(config['payid']);
            } else {
                payid_ng();
            }
            for (var i = 1; i <= radiobutton_max; i++) {
                config['plugin-radiobutton-field' + i] && ($('#plugin-radiobutton-field' + i).val(config['plugin-radiobutton-field' + i]));
            }

        });

        $('#plugin-submit').click(function () {
            var config = {};
            config['payid'] = $('#payid').val();
            if (!config['payid']) {
                config['payid'] = "";
            }
            for (var i = 1; i <= radiobutton_max; i++) {
                config['plugin-radiobutton-field' + i] = $('#plugin-radiobutton-field' + i).val();
            }
            config['group'] = group.join(',');

            kintone.plugin.app.setConfig(config);
        });

        $('#paycheck').click(function () {
            //API Gatewayを経由して、kintone内の購入アプリに保存してある支払いIDを取得
            //取得できなければ'NG'を返す
            document.getElementById('paycheckstatus').innerText = 'お支払い情報確認中。。。。。';
            payCheck(PLUGIN_ID, payCheckResult);
        });

        $('#pay').click(function () {
            //API Gatewayを経由して、pay.jpへ支払いリクエスト。

            document.getElementById('paystatus').innerText = 'お支払い処理中。しばらくお待ち下さい。。。。';
            checkout(PLUGIN_ID, checkoutResult);
        });

        $('#plugin-cancel').click(function () {
            history.back();
        });

    });
})(jQuery, kintone.$PLUGIN_ID);
