//--------------------------------------------------------------------------------------------------------------
//  ラジオボタンでグループの表示切り替えプラグイン
//  
//  By okiyasu
//--------------------------------------------------------------------------------------------------------------
jQuery.noConflict();

(function ($, PLUGIN_ID) {
    "use strict";

    // ラジオボタンのフィールドコードを取得
    var config = kintone.plugin.app.getConfig(PLUGIN_ID);
    var radiobutton = {};
    var radiobuttonmax = 3;
    for (var i = 1; i <= radiobuttonmax; i++) {
        radiobutton[i] = config['plugin-radiobutton-field' + i];
    }
    var GROUP = (config['group']).split(',');
    var PAYID = config['payid'];
    if (!PAYID || PAYID === '') {
        PAYID = 'none';
    }

    var storage = sessionStorage;
    var appId = kintone.app.getId();
    var storageKey = "pluginAuth_" + PLUGIN_ID + '_' + appId

    //レコードの追加、編集、詳細画面、ラジオボタン操作で適用する
    var events = [
        'app.record.detail.show',
        'app.record.create.show',
        'app.record.edit.show'
    ];
    for (var i = 1; i <= radiobuttonmax; i++) {
        if (radiobutton[i] === '') {
            continue;
        }
        events.push('app.record.create.change.' + radiobutton[i]);
        events.push('app.record.edit.change.' + radiobutton[i]);
    }

    function updateFieldcode() {
        var group = new Array();
        kintone.api(kintone.api.url('/k/v1/app/form/fields', true), 'GET', {'app': kintone.app.getId()}, function (resp) {
            $.each(resp['properties'], function (index, property) {
                if (property['type'] === 'GROUP') {
                    group.push(property['code']);
                }
            });
            var config = kintone.plugin.app.getConfig(PLUGIN_ID);
            if (group.join(',') === config['group']) {
                //設定画面で更新
                showMessage('フィールド情報は最新です', '確認完了', 'success');
            } else {
                showMessage('フィールド情報が最新ではありません。プラグイン設定画面で再度保存を押してください。', '設定を更新してください', 'warning');
            }
        });
    }

    function getSubdomain() {
        var subdomain = kintone.api.url('/k/v1/records');
        return subdomain.slice(subdomain.indexOf('/') + 2, subdomain.indexOf('.'));
    }

    function authPlugin(PLUGIN_ID, callback) {
        var url = 'https://ca6ouejz4h.execute-api.ap-northeast-1.amazonaws.com/prod/pluginauth';
        var param = {
            param: {
                subdomain: getSubdomain(),
                pluginid: PLUGIN_ID,
                appid: appId,
                orderid: PAYID
            }
        }
        kintone.proxy(url, 'POST', {}, param, function (body, status, headers) {
            if (status === 200) {
                var json_body = JSON.parse(body);
                if (json_body.result === 'OK') {
                    callback(true, json_body.message);
                } else {
                    callback(false, json_body.message);
                }
            } else {
                // 200以外はサーバー障害の可能性があるので認証通す
                callback(true, '');
            }
        }, function (body) {
            console.log(body);
            //ネットワークエラー（早めに画面移動してもここにくる、はず）時は、正常に変更
            callback(true, '');
        });
    }

    // 認証後
    var authPluginResult = function (res, message) {
        if (res) {
            storage.setItem(storageKey, "OK");
            showMessage(message, '認証成功', 'success');
        } else {
            storage.setItem(storageKey, "NG");
            showMessage(message, '認証失敗', 'error');
        }
    };

    function showMessage(message, title, type) {
        if (message === 'undefined' || message === '') {
            return;
        }
        title = title || '';
        type = type || 'success'; //"warning", "error", "success" and "info" 

        swal({
            title: title,
            text: message,
            type: type,
            confirmButtonText: "OK",
            closeOnConfirm: true
        },
        function () {
            //なにもしない
            ;
        });
    }

    kintone.events.on('app.record.index.show', function (event) {
//        storage.setItem(storageKey, "");
        var button_name = 'update_fieldcode_button';
        //ボタン追加で、押すとフィールド情報更新
        if (document.getElementById(button_name) != null) {
            return;
        }
        var updateFieldcodeButton = document.createElement('button');
        updateFieldcodeButton.id = button_name;
        updateFieldcodeButton.innerHTML = 'フィールド情報設定確認';
        updateFieldcodeButton.classList.add('kintoneplugin-button-dialog-ok');

        kintone.app.getHeaderMenuSpaceElement().appendChild(updateFieldcodeButton);
        // ボタンクリック時の処理
        updateFieldcodeButton.onclick = function () {
            updateFieldcode();
        }
        return event;
    });

    kintone.events.on(events, function (event) {
        var record = event.record;
        // 認証情報を確認して、ダメな場合は全グループ表示して終了
        // ストレージには、OK or NGが格納されている
        var authStr = storage.getItem(storageKey);
        if (authStr === 'NG') {
            for (var i = 0; i < GROUP.length; i++) {
                kintone.app.record.setFieldShown(GROUP[i], true);
                kintone.app.record.setGroupFieldOpen(GROUP[i], true);
            }
            return event;
        }
        if (authStr === '') {
            authPlugin(PLUGIN_ID, authPluginResult);
        }

        // 一度、全部非表示        
        for (var i = 0; i < GROUP.length; i++) {
            kintone.app.record.setFieldShown(GROUP[i], false);
        }

        //ラジオボタンに設定されてれば変更
        for (var i = 1; i <= radiobuttonmax; i++) {
            if (radiobutton[i] === '') {
                continue;
            }
            var radio = record[radiobutton[i]]['value'];
            kintone.app.record.setFieldShown(radiobutton[i] + '_' + radio, true);
            kintone.app.record.setGroupFieldOpen(radiobutton[i] + '_' + radio, true);
        }

        return event;
    });
})(jQuery, kintone.$PLUGIN_ID);
